@@ -47,8 +47,12 @@ for to be recovered on the next startup of your application.
     to access this config section directly then please
     use this constant instead of the hardcoded section name.
 
+
 .. _app-state-variables:
 
+app state variables
+^^^^^^^^^^^^^^^^^^^
+
 This module is providing/pre-defining the following application state variables:
 
     * :attr:`~MainAppBase.flow_id`
@@ -98,8 +102,12 @@ implementing main app instance has to call the method
 done e.g. after the app state has changed or at least
 on quiting the application.
 
+
 .. _app-state-constants:
 
+app state constants
+^^^^^^^^^^^^^^^^^^^
+
 This module is also providing some pre-defined constants
 that can be optionally used in your application in relation
 to the app states data store and for the app state config
@@ -196,7 +204,7 @@ the following order:
 
 
 application state change and save events
-________________________________________
+----------------------------------------
 
 Notification events get fired when one of the app state variables
 gets changed - like e.g. the :ref:`application flow` or if
@@ -224,7 +232,7 @@ be stored/saved.
 
 
 application flow change events
-______________________________
+------------------------------
 
 The name of the event method that gets fired when the app want
 to change the flow (via the method :meth:`~MainAppBase.change_flow`)
@@ -252,7 +260,7 @@ focus flow id.
 
 
 key press events
-________________
+----------------
 
 For to provide key press events to the applications that will use the new
 GUI framework you have to catch the key press events of the framework,
@@ -369,7 +377,7 @@ calling the first method that got returned by :meth:`~MainAppBase.init_app`.
 
 
 optional configuration and extension
-____________________________________
+------------------------------------
 
 Most of the base implementation helper methods can be overwritten by
 either the inheriting framework portion or directly by user main app
@@ -389,7 +397,7 @@ from ae.core import DEBUG_LEVELS                                    # type: igno
 from ae.console import ConsoleApp                                   # type: ignore
 
 
-__version__ = '0.0.31'
+__version__ = '0.0.33'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -947,11 +955,11 @@ class MainAppBase(ConsoleApp, ABC):
 
     def load_images(self):
         """ load images from app folder img. """
-        self.image_files = FilesRegister('img')
+        self.image_files = FilesRegister('img/**')
 
     def load_sounds(self):
         """ load audio sounds from app folder snd. """
-        self.sound_files = FilesRegister('snd')
+        self.sound_files = FilesRegister('snd/**')
 
     def play_beep(self):
         """ make a short beep sound, should be overwritten by GUI framework. """
